@@ -13,7 +13,7 @@ from tqdm import tqdm
 
 from TTBenchmark.check_environment import check_env_info
 from TTBenchmark.constant import GDRIVE_PATH
-from gen_benchmark import _get_benchmark_path
+from TTBenchmark.gen_benchmark import _get_benchmark_path
 
 
 class BenchmarkData:
